define('ember-local-storage/mixins/storage', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  exports['default'] = Ember['default'].Mixin.create({
    storageKey: null,
    initialContent: null,

    init: function() {
      var storage = this.storage(),
        storageKey = this.get('storageKey'),
        initialContent = this.get('initialContent'),
        serialized,
        content;

      if (this.get('localStorageKey')) {
        storageKey = this.get('localStorageKey');
        Ember['default'].deprecate('Usage of localStorageKey is deprecated use storageKey instead.');
      }

      if (!storageKey) {
        throw new Error('You must specify which property name should be used to save ' + this + ' in ' + this.get('_storage') + 'Storage by setting its storageKey property.');
      }

      if (!initialContent) {
        throw new Error('You must specify the initialContent.');
      }

      // Retrieve the serialized version from storage using the specified
      // key.
      serialized = storage[storageKey];

      // Merge the serialized version into defaults.
      content = initialContent;
      if (serialized) {
        content = Ember['default'].merge(content, JSON.parse(serialized));
      }

      this.set('content', content);

      return this._super.apply(this, arguments);
    },

    save: function() {
      var storage = this.storage(),
        content = this.get('content'),
        storageKey = this.get('storageKey');

      storage[storageKey] = JSON.stringify(content);
    },

    storage: function() {
      return (this.get('_storage') === 'local') ? localStorage : sessionStorage;
    }
  });

});