define('dummy/tests/unit/components/lazy-image-test', ['ember', 'ember-qunit', 'ember-lazy-image/lib/cache'], function (Ember, ember_qunit, Cache) {

  'use strict';

  ember_qunit.moduleForComponent("lazy-image", "LazyImageComponent");

  var run = Ember['default'].run;
  var get = Ember['default'].get;

  var imageSelector = ".lazy-image";
  var placeholderSelector = ".lazy-image-placeholder";
  var errorMessageSelector = ".lazy-image-error-message";
  var imageContainerSelector = ".lazy-image-container";

  ember_qunit.test("it has correct defaults", function (assert) {
    assert.expect(4);

    var component = this.subject();

    assert.equal(get(component, "loaded"), false);
    assert.equal(get(component, "errorThrown"), false);
    assert.equal(get(component, "lazyUrl"), "//:0");
    assert.equal(get(component, "defaultErrorText"), "Image failed to load");
  });

  ember_qunit.test("it renders default placeholder", function (assert) {
    assert.expect(1);

    var component = this.subject();

    this.render();

    assert.ok(component.$(placeholderSelector).length > 0, "placeholder is correctly rendered");
  });

  ember_qunit.test("it renders default error message if image fails to load", function (assert) {
    assert.expect(2);

    var component = this.subject();

    component._imageError();

    this.render();

    assert.ok(component.$(errorMessageSelector).length > 0, "error message is correctly rendered");
    assert.ok(component.$(errorMessageSelector + ":contains(\"" + "Image failed to load" + "\")"), "default error message is rendered correctly");
  });

  ember_qunit.test("it leverages cache", function (assert) {
    // Setup sessionStorage
    window.sessionStorage.clear();

    run(function () {
      Cache['default'].create();
    });

    assert.expect(1);

    var component = this.subject({
      url: "http://emberjs.com/images/team/tdale.jpg"
    });

    this.render();

    run(function () {
      component.set("enteredViewport", true);
    });

    var lazyImages = window.sessionStorage["ember-lazy-images"];
    var cache = lazyImages ? JSON.parse(lazyImages) : lazyImages;

    assert.deepEqual(cache, {
      emberjscomimagesteamtdalejpg: true
    });
  });

  ember_qunit.test("`width` and `height` bindings work correctly", function (assert) {
    assert.expect(2);

    var component = this.subject({
      width: 400,
      height: 400
    });

    this.render();

    assert.equal(component.$("img").attr("width"), 400, "width is correct");
    assert.equal(component.$("img").attr("height"), 400, "height is correct");
  });

  ember_qunit.test("`data-*` attribute bindings work correctly", function (assert) {
    assert.expect(1);

    var component = this.subject({
      "data-person-id": 1234
    });

    this.render();

    assert.equal(component.$("img").attr("data-person-id"), 1234, "data attribute is correct is correct");
  });

});