define('ember-lazy-image/components/lazy-image', ['exports', 'ember-lazy-image/lib/cache', 'ember', 'ember-lazy-image/mixins/image-load', 'ember-lazy-image/mixins/in-viewport'], function (exports, Cache, Ember, ImageLoadMixin, InViewportMixin) {

  'use strict';

  var on        = Ember['default'].on;
  var get       = Ember['default'].get;
  var set       = Ember['default'].set;
  var keys      = Ember['default'].keys;
  var observer  = Ember['default'].observer;
  var computed  = Ember['default'].computed;
  var dasherize = Ember['default'].String.dasherize;
  var Component = Ember['default'].Component;

  exports['default'] = Component.extend(InViewportMixin['default'], ImageLoadMixin['default'], {
    _cache: Cache['default'].create(),

    lazyUrl: "//:0",

    classNames: ['lazy-image-container'],

    setupAttributes: on('didInsertElement', function() {
      var img       = this.$('img');
      var component = this;

      keys(component).forEach(function(key) {
        if (key.substr(0, 5) === 'data-') {
          img.attr(key, component.get(key));
        }
      });
    }),

    setImageUrl: observer('enteredViewport', function() {
      var url             = get(this, 'url');
      var cache           = get(this, '_cache');
      var lazyUrl         = get(this, 'lazyUrl');
      var cacheKey        = get(this, '_cacheKey');
      var enteredViewport = get(this, 'enteredViewport');

      if (cacheKey && get(cache, cacheKey)) {
        set(this, 'lazyUrl', url);
      }

      if (enteredViewport && lazyUrl === "//:0") {
        set(this, 'lazyUrl', url);

        if (cacheKey) {
          set(cache, cacheKey, true);
        }
      }
    }).on('didInsertElement'),

    _cacheKey: computed('url', function() {
      var url = this.get('url');
      var key;

      if (url) {
        key = dasherize(url.replace(/^http[s]?\:\/\/|\.|\//g, ''));
      }

      if (key) {
        return key;
      }
    })
  });

});