define('ember-lazy-image/mixins/image-load', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  var on             = Ember['default'].on;
  var set            = Ember['default'].set;
  var run            = Ember['default'].run;
  var Mixin          = Ember['default'].Mixin;
  var computed       = Ember['default'].computed;
  var getWithDefault = Ember['default'].getWithDefault;

  exports['default'] = Mixin.create({
    loaded:      false,
    errorThrown: false,

    classNameBindings: ['loaded', 'errorThrown'],

    defaultErrorText: computed('errorText', function() {
      return getWithDefault(this, 'errorText', 'Image failed to load');
    }),

    _resolveImage: on('didInsertElement', function() {
      var component = this;
      var image     = component.$('img');
      var isCached  = image[0].complete;

      if (!isCached) {
        image.on('load', function() {
          component._imageLoaded();
        });

        image.on('error', function(error) {
          component._imageError(error);
        });
      } else {
        this._imageLoaded();
      }
    }),

    _imageLoaded: function() {
      var component = this;

      run(function() {
        set(component, 'loaded', true);
      });
    },

    _imageError: function() {
      var component = this;

      run(function() {
        set(component, 'errorThrown', true);
      });
    },

    willDestroyElement: function() {
      this.$('img').off('load');
      this.$('img').off('error');
    }
  });

});