define('ember-lazy-image/mixins/in-viewport', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  // Inspired by Lauren Tan
  // https://medium.com/delightful-ui-for-ember-apps/ember-js-detecting-if-a-dom-element-is-in-the-viewport-eafcc77a6f86

  var on           = Ember['default'].on;
  var get          = Ember['default'].get;
  var Mixin        = Ember['default'].Mixin;
  var debounce     = Ember['default'].run.debounce;
  var scheduleOnce = Ember['default'].run.scheduleOnce;

  exports['default'] = Mixin.create({
    scrollTimeout:   100,
    enteredViewport: null,
    threshold:       0,

    _setViewport: function() {
      var rect      = this.$() ? this.$()[0].getBoundingClientRect() : null;
      var threshold = get(this, 'threshold');

      if (!rect) {
        return;
      }

      this.set('enteredViewport',
        rect.top >= 0 &&
        rect.left >= 0 &&
        (rect.bottom - threshold) <= (window.innerHeight || document.documentElement.clientHeight) &&
        (rect.right - threshold) <= (window.innerWidth || document.documentElement.clientWidth)
      );
    },

    _setInitialViewport: on('didInsertElement', function() {
      scheduleOnce('afterRender', this, function() {
        this._setViewport();
      });
    }),

    _scrollHandler: function() {
      debounce(this, function() {
        this._setViewport();
      }, get(this, 'scrollTimeout'));
    },

    _bindScroll: on('didInsertElement', function() {
      var component = this;

      Ember['default'].$(document).on('touchmove.scrollable', function() {
        component._scrollHandler();
      });

      Ember['default'].$(window).on('scroll.scrollable', function() {
        component._scrollHandler();
      });

      Ember['default'].$(window).on('resize.resizable', function() {
        component._scrollHandler();
      });
    }),

    _unbindScroll: on('willDestroyElement', function() {
      Ember['default'].$(window).off('.scrollable');
      Ember['default'].$(window).off('.resizable');
      Ember['default'].$(document).off('.scrollable');
    }),
  });

});