define("ember-lazy-image", ["ember-lazy-image/index","exports"], function(__index__, __exports__) {
  "use strict";
  Object.keys(__index__).forEach(function(key){
    __exports__[key] = __index__[key];
  });
});

define('ember-lazy-image/components/lazy-image', ['exports', 'ember-lazy-image/lib/cache', 'ember', 'ember-lazy-image/mixins/image-load', 'ember-lazy-image/mixins/in-viewport'], function (exports, Cache, Ember, ImageLoadMixin, InViewportMixin) {

  'use strict';

  var on        = Ember['default'].on;
  var get       = Ember['default'].get;
  var set       = Ember['default'].set;
  var keys      = Ember['default'].keys;
  var observer  = Ember['default'].observer;
  var computed  = Ember['default'].computed;
  var dasherize = Ember['default'].String.dasherize;
  var Component = Ember['default'].Component;

  exports['default'] = Component.extend(InViewportMixin['default'], ImageLoadMixin['default'], {
    _cache: Cache['default'].create(),

    lazyUrl: "//:0",

    classNames: ['lazy-image-container'],

    setupAttributes: on('didInsertElement', function() {
      var img       = this.$('img');
      var component = this;

      keys(component).forEach(function(key) {
        if (key.substr(0, 5) === 'data-') {
          img.attr(key, component.get(key));
        }
      });
    }),

    setImageUrl: observer('enteredViewport', function() {
      var url             = get(this, 'url');
      var cache           = get(this, '_cache');
      var lazyUrl         = get(this, 'lazyUrl');
      var cacheKey        = get(this, '_cacheKey');
      var enteredViewport = get(this, 'enteredViewport');

      if (cacheKey && get(cache, cacheKey)) {
        set(this, 'lazyUrl', url);
      }

      if (enteredViewport && lazyUrl === "//:0") {
        set(this, 'lazyUrl', url);

        if (cacheKey) {
          set(cache, cacheKey, true);
        }
      }
    }).on('didInsertElement'),

    _cacheKey: computed('url', function() {
      var url = this.get('url');
      var key;

      if (url) {
        key = dasherize(url.replace(/^http[s]?\:\/\/|\.|\//g, ''));
      }

      if (key) {
        return key;
      }
    })
  });

});
define('ember-lazy-image/lib/cache', ['exports', 'ember-local-storage/session/object'], function (exports, StorageObject) {

  'use strict';

  exports['default'] = StorageObject['default'].extend({
    storageKey: 'ember-lazy-images'
  });

});
define('ember-lazy-image/mixins/image-load', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  var on             = Ember['default'].on;
  var set            = Ember['default'].set;
  var run            = Ember['default'].run;
  var Mixin          = Ember['default'].Mixin;
  var computed       = Ember['default'].computed;
  var getWithDefault = Ember['default'].getWithDefault;

  exports['default'] = Mixin.create({
    loaded:      false,
    errorThrown: false,

    classNameBindings: ['loaded', 'errorThrown'],

    defaultErrorText: computed('errorText', function() {
      return getWithDefault(this, 'errorText', 'Image failed to load');
    }),

    _resolveImage: on('didInsertElement', function() {
      var component = this;
      var image     = component.$('img');
      var isCached  = image[0].complete;

      if (!isCached) {
        image.on('load', function() {
          component._imageLoaded();
        });

        image.on('error', function(error) {
          component._imageError(error);
        });
      } else {
        this._imageLoaded();
      }
    }),

    _imageLoaded: function() {
      var component = this;

      run(function() {
        set(component, 'loaded', true);
      });
    },

    _imageError: function() {
      var component = this;

      run(function() {
        set(component, 'errorThrown', true);
      });
    },

    willDestroyElement: function() {
      this.$('img').off('load');
      this.$('img').off('error');
    }
  });

});
define('ember-lazy-image/mixins/in-viewport', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  // Inspired by Lauren Tan
  // https://medium.com/delightful-ui-for-ember-apps/ember-js-detecting-if-a-dom-element-is-in-the-viewport-eafcc77a6f86

  var on           = Ember['default'].on;
  var get          = Ember['default'].get;
  var Mixin        = Ember['default'].Mixin;
  var debounce     = Ember['default'].run.debounce;
  var scheduleOnce = Ember['default'].run.scheduleOnce;

  exports['default'] = Mixin.create({
    scrollTimeout:   100,
    enteredViewport: null,
    threshold:       0,

    _setViewport: function() {
      var rect      = this.$() ? this.$()[0].getBoundingClientRect() : null;
      var threshold = get(this, 'threshold');

      if (!rect) {
        return;
      }

      this.set('enteredViewport',
        rect.top >= 0 &&
        rect.left >= 0 &&
        (rect.bottom - threshold) <= (window.innerHeight || document.documentElement.clientHeight) &&
        (rect.right - threshold) <= (window.innerWidth || document.documentElement.clientWidth)
      );
    },

    _setInitialViewport: on('didInsertElement', function() {
      scheduleOnce('afterRender', this, function() {
        this._setViewport();
      });
    }),

    _scrollHandler: function() {
      debounce(this, function() {
        this._setViewport();
      }, get(this, 'scrollTimeout'));
    },

    _bindScroll: on('didInsertElement', function() {
      var component = this;

      Ember['default'].$(document).on('touchmove.scrollable', function() {
        component._scrollHandler();
      });

      Ember['default'].$(window).on('scroll.scrollable', function() {
        component._scrollHandler();
      });

      Ember['default'].$(window).on('resize.resizable', function() {
        component._scrollHandler();
      });
    }),

    _unbindScroll: on('willDestroyElement', function() {
      Ember['default'].$(window).off('.scrollable');
      Ember['default'].$(window).off('.resizable');
      Ember['default'].$(document).off('.scrollable');
    }),
  });

});
define("ember-local-storage", ["ember-local-storage/index","exports"], function(__index__, __exports__) {
  "use strict";
  Object.keys(__index__).forEach(function(key){
    __exports__[key] = __index__[key];
  });
});

define('ember-local-storage/local/array', ['exports', 'ember', 'ember-local-storage/mixins/array'], function (exports, Ember, ArrayProxyMixin) {

  'use strict';

  exports['default'] = Ember['default'].ArrayProxy.extend(ArrayProxyMixin['default'], {
    _storage: 'local'
  });

});
define('ember-local-storage/local/object', ['exports', 'ember', 'ember-local-storage/mixins/object'], function (exports, Ember, ObjectProxyMixin) {

  'use strict';

  exports['default'] = Ember['default'].ObjectProxy.extend(ObjectProxyMixin['default'], {
    _storage: 'local'
  });

});
define('ember-local-storage/mixins/array', ['exports', 'ember', 'ember-local-storage/mixins/storage'], function (exports, Ember, StorageProxyMixin) {

  'use strict';

  exports['default'] = Ember['default'].Mixin.create(StorageProxyMixin['default'], {
    initialContent: [],

    replaceContent: function(idx, amount, objects) {
      this._super(idx, amount, objects);
      this.save();
    }
  });

});
define('ember-local-storage/mixins/object', ['exports', 'ember', 'ember-local-storage/mixins/storage'], function (exports, Ember, StorageProxyMixin) {

  'use strict';

  exports['default'] = Ember['default'].Mixin.create(StorageProxyMixin['default'], {
    initialContent: {},

    setUnknownProperty: function (key, value) {
      this._super(key, value);
      this.save();
    },

    set: function(keyName, value) {
      this._super(keyName, value);
      this.save();
    }
  });

});
define('ember-local-storage/mixins/storage', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  exports['default'] = Ember['default'].Mixin.create({
    storageKey: null,
    initialContent: null,

    init: function() {
      var storage = this.storage(),
        storageKey = this.get('storageKey'),
        initialContent = this.get('initialContent'),
        serialized,
        content;

      if (this.get('localStorageKey')) {
        storageKey = this.get('localStorageKey');
        Ember['default'].deprecate('Usage of localStorageKey is deprecated use storageKey instead.');
      }

      if (!storageKey) {
        throw new Error('You must specify which property name should be used to save ' + this + ' in ' + this.get('_storage') + 'Storage by setting its storageKey property.');
      }

      if (!initialContent) {
        throw new Error('You must specify the initialContent.');
      }

      // Retrieve the serialized version from storage using the specified
      // key.
      serialized = storage[storageKey];

      // Merge the serialized version into defaults.
      content = initialContent;
      if (serialized) {
        content = Ember['default'].merge(content, JSON.parse(serialized));
      }

      this.set('content', content);

      return this._super.apply(this, arguments);
    },

    save: function() {
      var storage = this.storage(),
        content = this.get('content'),
        storageKey = this.get('storageKey');

      storage[storageKey] = JSON.stringify(content);
    },

    storage: function() {
      return (this.get('_storage') === 'local') ? localStorage : sessionStorage;
    }
  });

});
define('ember-local-storage/session/array', ['exports', 'ember', 'ember-local-storage/mixins/array'], function (exports, Ember, ArrayProxyMixin) {

  'use strict';

  exports['default'] = Ember['default'].ArrayProxy.extend(ArrayProxyMixin['default'], {
    _storage: 'session'
  });

});
define('ember-local-storage/session/object', ['exports', 'ember', 'ember-local-storage/mixins/object'], function (exports, Ember, ObjectProxyMixin) {

  'use strict';

  exports['default'] = Ember['default'].ObjectProxy.extend(ObjectProxyMixin['default'], {
    _storage: 'session'
  });

});//# sourceMappingURL=addons.map